@@ -1,18 +1,32 @@
 #ifndef _LSDVD_H_
 #define _LSDVD_H_
 
-extern char *video_format[2];
-extern char *aspect_ratio[4];
-extern char *quantization[4];
-extern char *mpeg_version[2];
-extern char *video_height[4];
-extern char *video_width[4];
-extern char *permitted_df[4];
-extern char *audio_format[7];
+#ifdef __linux__
+#define DEFAULT_DVD_DEVICE "/dev/sr0"
+#elif __FreeBSD__ || __DragonFly__
+#define DEFAULT_DVD_DEVICE "/dev/acd0"
+#elif __NetBSD__
+#define DEFAULT_DVD_DEVICE "/dev/cd0d"
+#elif __OpenBSD__
+#define DEFAULT_DVD_DEVICE "/dev/cd0c"
+#elif __APPLE__ && __MACH__
+#define DEFAULT_DVD_DEVICE "/dev/disk1"
+#else
+#define DEFAULT_DVD_DEVICE "/dev/dvd"
+#endif
+
+extern const char *video_format[2];
+extern const char *aspect_ratio[4];
+extern const char *quantization[4];
+extern const char *mpeg_version[2];
+extern const char *video_height[2][4];
+extern const char *video_width[4];
+extern const char *permitted_df[4];
+extern const char *audio_format[7];
 extern int audio_id[7];
-extern char *sample_freq[2];
-extern char *audio_type[5];
-extern char *subp_type[16];
+extern const char *sample_freq[2];
+extern const char *audio_type[5];
+extern const char *subp_type[16];
 extern double frames_per_s[4];
 extern char *program_name;
 
@@ -46,11 +60,11 @@ struct dvd_info {
 			int vts;
 			int ttn;
 			float fps;
-			char *format;
-			char *aspect;
-			char *width;
-			char *height;
-			char *df;
+			const char *format;
+			const char *aspect;
+			const char *width;
+			const char *height;
+			const char *df;
 		} parameter;
 		int angle_count; /* no real angle detail is available... but hey. */
 		int audiostream_count_reported; /* This includes all audio streams, active or not */
@@ -58,12 +72,12 @@ struct dvd_info {
 		struct {
 			char *langcode;
 			char *language;
-			char *format;
-			char *frequency;
-			char *quantization;
+			const char *format;
+			const char *frequency;
+			const char *quantization;
 			int channels;
 			int ap_mode;
-			char *content;
+			const char *content;
 			int streamid;
 		} *audiostreams;
 		int chapter_count_reported; /* This value is sometimes wrong */
@@ -85,12 +99,13 @@ struct dvd_info {
 		struct {
 			char *langcode;
 			char *language;
-			char *content;
+			const char *content;
 			int streamid;
 		} *subtitles;
 		int *palette;
 	} *titles;
 	int longest_track;
+	char dvddiscid[16*2+1]; // 128 bit MD5 sum as hex number
 };
 
 void ohuman_print(struct dvd_info *dvd_info);
